deeplake.api.tiled
==================
.. currentmodule:: deeplake.api.tiled
.. function:: tiled(sample_shape: Tuple[int, ...], tile_shape: Optional[Tuple[int, ...]] = None, dtype: Union[str, np.dtype] = np.dtype("uint8"))

    See :func:`deeplake.tiled`.